@@ -485,7 +485,7 @@ void AudioSetup::updateSource(const pa_source_info* i)
     if (false && info.ports.size()) {
         int idx = deviceBox->currentIndex();
         if (idx >= 0) {
-            int64_t index = deviceBox->itemData(idx).toInt();
+            qint64 index = deviceBox->itemData(idx).toInt();
             if (index < 0 && ((-1*index) - 1) == i->index) {
                 portBox->blockSignals(true);
                 portBox->setCurrentIndex(portBox->findData(info.activePort));
@@ -603,8 +603,7 @@ void AudioSetup::profileChanged()
     QString profile = profileBox->itemData(profileBox->currentIndex()).toString();
     kDebug() << "Changing profile to" << profile;
 
-    cardInfo &card_info = s_Cards[card_index];
-    Q_ASSERT(card_info.profiles.size());
+    Q_ASSERT(s_Cards[card_index].profiles.size());
 
     pa_operation *operation =
             pa_context_set_card_profile_by_index(s_context,
@@ -666,7 +665,7 @@ void AudioSetup::reallyUpdateVUMeter()
         inputLevels->setValue(val-1);
 }
 
-static deviceInfo &getDeviceInfo(int64_t index)
+static deviceInfo &getDeviceInfo(qint64 index)
 {
     if (index >= 0) {
       Q_ASSERT(s_Sinks.contains(index));
@@ -687,7 +686,7 @@ void AudioSetup::deviceChanged()
         _updatePlacementTester();
         return;
     }
-    int64_t index = deviceBox->itemData(idx).toInt();
+    qint64 index = deviceBox->itemData(idx).toInt();
     deviceInfo &device_info = getDeviceInfo(index);
 
     kDebug() << QString("Updating ports for device '%1' (%2 ports available)")
@@ -723,13 +722,15 @@ void AudioSetup::deviceChanged()
 
 void AudioSetup::portChanged()
 {
-    int64_t index = deviceBox->itemData(deviceBox->currentIndex()).toInt();
+    qint64 index = deviceBox->itemData(deviceBox->currentIndex()).toInt();
 
     QString port = portBox->itemData(portBox->currentIndex()).toString();
     kDebug() << "Changing port to" << port;
 
+#ifndef QT_NO_DEBUG
     deviceInfo &device_info = getDeviceInfo(index);
     Q_ASSERT(device_info.ports.size());
+#endif /* QT_NO_DEBUG */
 
     pa_operation *o;
     if (index >= 0) {
@@ -778,7 +779,7 @@ void AudioSetup::_updatePlacementTester()
     if (idx < 0)
       return;
 
-    int64_t index = deviceBox->itemData(idx).toInt();
+    qint64 index = deviceBox->itemData(idx).toInt();
     deviceInfo& sink_info = getDeviceInfo(index);
 
     if (index < 0) {
